# SPDX-License-Identifier: CC0-1.0

let
  tests = call:
    {
      fs_report = call ./fs_report.nix { };
      log = call ./log.nix { };
      signal = call ./signal.nix { };
    } // call ./solo5 { };

in { self, apps, system, localSystem, crossSystem, genodepkgs, nixpkgs
, genode-depot, lib }:

let
  hostPkgs = import nixpkgs { system = localSystem; };
  depot = builtins.getAttr crossSystem genode-depot.packages;
  testPkgs = genodepkgs;

  linux = tests (import ./driver-linux.nix {
    inherit apps testPkgs hostPkgs lib depot;
  }).callTest;

  nova = (call: ((tests call) // { pci = call ./pci.nix { }; }))
    (import ./driver-nova.nix {
      inherit apps system testPkgs hostPkgs lib depot;
    }).callTest;

  sotest-nova = (call: ((tests call) // { pci = call ./pci.nix { }; }))
    (import ./driver-sotest-nova.nix {
      inherit apps system testPkgs hostPkgs lib depot;
    }).callTest;

  testsToList = tests:
    map (test: {
      inherit (test) name;
      value = test;
    }) (builtins.attrValues tests);

in with builtins;
listToAttrs (concatLists (map (testsToList) [ linux nova sotest-nova ]))
